### R code from vignette source 'pbcmc-vignette.Rnw'
### Encoding: UTF-8

###################################################
### code chunk number 1: General options for R
###################################################
options(prompt="R> ", continue="+  ", width=70, useFancyQuotes=FALSE, digits=4) 
suppressMessages(library("pbcmc"))


###################################################
### code chunk number 2: Loading datasets
###################################################
library("pbcmc")
library("BiocParallel")
object<-loadBCDataset(Class=PAM50, libname="nki", verbose=TRUE)  
object


###################################################
### code chunk number 3: PAM50 with own data
###################################################
M<-pam50$centroids
genes<-pam50$centroids.map
names(genes)<-c("probe", "NCBI.gene.symbol", "EntrezGene.ID")  
object<-PAM50(exprs=M, annotation=genes)   
object


###################################################
### code chunk number 4: Exploring the slots
###################################################
head(exprs(object))      ##The gene expression values for each subject
head(annotation(object)) ##The compulsory annotation fields
head(targets(object))    ##The clinical data, if available.


###################################################
### code chunk number 5: Workflow
###################################################
object<-filtrate(object, verbose=TRUE)   
object<-classify(object, std="none", verbose=TRUE)  
object<-permutate(object, nPerm=10000, pCutoff=0.01, where="fdr", 
    corCutoff=0.1, keep=TRUE, seed=1234567890, verbose=TRUE, 
    BPPARAM=bpparam())


###################################################
### code chunk number 6: Permutation results
###################################################
object


###################################################
### code chunk number 7: Summary
###################################################
summary(object)


###################################################
### code chunk number 8: SubjectReport
###################################################
subjectReport(object, subject=1)   


###################################################
### code chunk number 9: Session Info
###################################################
sessionInfo()


